package com.jxdinfo.hussar.core.config;

package .tmp;

import com.jxdinfo.hussar.core.config.HussarConfig;
import com.jxdinfo.hussar.core.listener.CloudConfigListener;
import com.jxdinfo.hussar.core.listener.ConfigListener;
import com.jxdinfo.hussar.core.listener.ErrorTipInterceptor;
import com.jxdinfo.hussar.core.listener.RLInterceptor;
import java.util.EventListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.web.servlet.ServletListenerRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

@Configuration("hussar.securityconfig")
public class SecurityConfig implements WebMvcConfigurer {
  @Bean
  ServletListenerRegistrationBean<ConfigListener> configListenerRegistration(@Autowired ConfigListener paramConfigListener) {
    return new ServletListenerRegistrationBean((EventListener)paramConfigListener);
  }
  
  @Bean
  @ConditionalOnClass(name = {"org.springframework.cloud.client.discovery.DiscoveryClient"})
  ServletListenerRegistrationBean<CloudConfigListener> cloudConfigListenerRegistration(@Autowired CloudConfigListener paramCloudConfigListener) {
    return new ServletListenerRegistrationBean((EventListener)paramCloudConfigListener);
  }
  
  @Bean
  @ConditionalOnMissingBean({HussarConfig.class})
  HussarConfig hussarConfig() {
    return new HussarConfig();
  }
  
  @Bean
  @ConditionalOnMissingBean({RLInterceptor.class})
  HandlerInterceptor getInterceptor(HussarConfig paramHussarConfig) {
    return (HandlerInterceptor)new RLInterceptor(paramHussarConfig);
  }
  
  @Bean
  HandlerInterceptor errorTipInterceptor() {
    return (HandlerInterceptor)new ErrorTipInterceptor();
  }
  
  public void addInterceptors(InterceptorRegistry paramInterceptorRegistry) {
    paramInterceptorRegistry.addInterceptor(getInterceptor(hussarConfig())).addPathPatterns(new String[] { "/**" }).excludePathPatterns(new String[] { 
          "/qrcode/getPicture", "/license/**", "/security", "/kaptcha", "/login", "/logout", "/", "/global/423", "/redis/**", "/static/**", 
          "/resource/checkResource", "/exception/**", "/user/reChecking", "/userFront/reChecking", "/casonline/check", "/resourceFront/checkResource", "/frontLogin/**", "/oauth2/**", "/resourceFront/getResources", "/frontMenu/**", 
          "/licenseFront/**", "/getBackPwd/**", "/getBackPwdFront/**", "/vue/baseData/getBaseData", "/error", "/druid/**", "/casSyncMessageFront/**", "/monitor", "/redisFront/**", "/ehcacheFront/**", 
          "/homePage/**", "/unify/cas/**", "/themeConfig/**" });
    paramInterceptorRegistry.addInterceptor(errorTipInterceptor()).addPathPatterns(new String[] { "/**" });
  }
}
